package org.jboss.tools.examples.service;

import java.util.List;

import javax.ejb.Stateless;
import javax.inject.Inject;
import javax.persistence.EntityManager;

import org.hibernate.search.jpa.FullTextEntityManager;
import org.hibernate.search.jpa.Search;
import org.hibernate.search.query.dsl.QueryBuilder;
import org.jboss.tools.examples.model.Member;


@Stateless
public class MemberSearch
{
   @Inject
   private EntityManager em;
   
   public void reindex() throws InterruptedException {
      FullTextEntityManager fullTextEntityManager = Search.getFullTextEntityManager(em);
      fullTextEntityManager.createIndexer().startAndWait();
   }
   
   public List<Member> search(String queryString) {
      FullTextEntityManager fullTextEntityManager = 
            org.hibernate.search.jpa.Search.getFullTextEntityManager(em);

        // create native Lucene query unsing the query DSL
        // alternatively you can write the Lucene query using the Lucene query parser
        // or the Lucene programmatic API. The Hibernate Search DSL is recommended though
        QueryBuilder qb = fullTextEntityManager.getSearchFactory()
            .buildQueryBuilder().forEntity( Member.class ).get();
        org.apache.lucene.search.Query query = qb
          .keyword()
          .onFields("name", "email"/*, "dateOfBirth"*/)
          .matching(queryString)
          .createQuery();

        // wrap Lucene query in a javax.persistence.Query
        javax.persistence.Query persistenceQuery = 
            fullTextEntityManager.createFullTextQuery(query, Member.class);

        // execute search
        List<Member> result = (List<Member>)persistenceQuery.getResultList();

        return result;
   }
}
